Summary: The Linux kernel (the core of the Linux operating system)

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.

%define buildup 1
# Only used on archs without run-time support (ie ppc, sparc64)
%define buildsmp 0
%define buildpae 0
# Whether to apply the Xen patches, leave this enabled.
%define includexen 1
# Whether to build the Xen kernels, disable if you want.
%define buildxen 0
%define builddoc 0
%define buildkdump 0
%define buildheaders 0
%define builddebug 0

# Versions of various parts

# After branching, please hardcode these values as the
# %dist and %rhel tags are not reliable yet
# For example dist -> .el5 and rhel -> 5
#% define dist .XX
#% define rhel Y

#
# Polite request for people who spin their own kernel rpms:
# please modify the "release" field in a way that identifies
# that the kernel isn't the stock distribution kernel, for example by
# adding some text to the end of the version number.
#
%define sublevel 20
%define kversion 2.6.%{sublevel}
%define rpmversion 2.6.%{sublevel}
#%define release %(R="$Revision: 1.2319 $"; RR="${R##: }"; echo ${RR%%?})%{?dist}
%define release 1.2319.fc5.stk16
%define signmodules 0
%define xen_hv_cset 11774
%define make_target bzImage
%define kernel_image x86
%define xen_flags verbose=y crash_debug=y
%define xen_target vmlinuz
%define xen_image vmlinuz

%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}
%define hdrarch %_target_cpu

# groups of related archs
#OLPC stuff
%if 0%{?olpc}
%define buildxen 0
%define buildkdump 0
%endif
# Don't build 586 kernels for RHEL builds.
%if 0%{?rhel}
%define all_x86 i386 i686
# we differ here b/c of the reloc patches
%ifarch i686 x86_64
%define buildkdump 0
%endif
%else
%define all_x86 i386 i586 i686
%endif

# Override generic defaults with per-arch defaults

%ifarch noarch
%define builddoc 1
%define buildup 0
%define buildheaders 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-*.config
%endif

# Do debug builds on i686, x86_64
%ifarch i686 x86_64
%define builddebug 1
%endif

# kdump only builds on i686, x86_64, ppc64 ...
%ifnarch i686 x86_64 ppc64 ppc64iseries
%define buildkdump 0
%endif

# Xen only builds on i686, x86_64 and ia64 ...
%ifnarch i686 x86_64 ia64
%define buildxen 0
%endif

# Second, per-architecture exclusions (ifarch)

%ifarch ppc64iseries i686 i586
%define buildheaders 0
%endif

%ifarch %{all_x86}
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.config
%define image_install_path boot
%define signmodules 1
%define hdrarch i386
%endif

%ifarch i586 i686
%define buildsmp 1
# we build always xen HV with pae
%define xen_flags verbose=y crash_debug=y pae=y
%endif

%ifarch x86_64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config
%define image_install_path boot
%define signmodules 1
%endif

%ifarch ppc64 ppc64iseries
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64*.config
%define image_install_path boot
%define signmodules 1
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define hdrarch powerpc
%endif

%ifarch s390
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390*.config
%define image_install_path boot
%define make_target image
%define kernel_image arch/s390/boot/image
%endif

%ifarch s390x
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390x.config
%define image_install_path boot
%define make_target image
%define kernel_image arch/s390/boot/image
%define hdrarch s390
%endif

%ifarch sparc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc.config
%define make_target image
%define kernel_image image
%endif

%ifarch sparc64
%define buildsmp 1
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc64*.config
%define make_target image
%define kernel_image image
%endif

%ifarch ppc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc{-,.}*config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define buildsmp 1
%define hdrarch powerpc
%endif

%ifarch ia64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ia64*.config
%define image_install_path boot/efi/EFI/redhat
%define signmodules 1
%define make_target compressed
%define kernel_image vmlinux.gz
# ia64 xen HV doesn't building with debug=y at the moment
%define xen_flags verbose=y crash_debug=y
%define xen_target compressed
%define xen_image vmlinux.gz
%endif

# To temporarily exclude an architecture from being built, add it to
# %nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We don't build a kernel on i386 or s390x -- we only do kernel-headers there.
# We also don't support s390, iseries and ia64 on Fedora.
%define nobuildarches i386 s390 s390x ppc64iseries ia64

%ifarch %nobuildarches
%define buildup 0
%define buildsmp 0
%define buildpae 0
%define buildxen 0
%define buildkdump 0
%define _enable_debug_packages 0
%endif


#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
%define package_conflicts kudzu < 1.2.5, initscripts < 7.23, udev < 063-6, iptables < 1.3.2-1, ipw2200-firmware < 2.4, selinux-policy-targeted < 1.25.3-14

#
# The ld.so.conf.d file we install uses syntax older ldconfig's don't grok.
#
%define xen_conflicts glibc < 2.3.5-1, xen < 3.0.1

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 4.2.21-1

Name: kernel
Group: System Environment/Kernel
License: GPLv2
Version: %{rpmversion}
Release: %{release}
%if 0%{?olpc}
ExclusiveArch: i386 i586
%else
# DO NOT CHANGE THIS LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch %{all_x86} x86_64 ppc ppc64 ppc64iseries ia64 sparc sparc64 s390 s390x
%endif
ExclusiveOS: Linux
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
# KMP - We need this for the moment
#AutoReqProv: no
AutoReqProv: yes


#
# List the packages used during the kernel build
#
BuildPreReq: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildPreReq: bzip2, findutils, gzip, m4, perl, make >= 3.78, diffutils
%if %{signmodules}
BuildPreReq: gnupg
%endif
BuildRequires: gcc >= 3.4.2, binutils >= 2.12, redhat-rpm-config
%if %{buildheaders}
BuildRequires: unifdef
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb


Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{kversion}.tar.bz2
Source1: xen-3.0.3-%{xen_hv_cset}.tar.bz2
Source2: Config.mk

Source10: COPYING.modules
Source11: genkey
Source12: kabitool
Source14: find-provides
Source15: merge.pl

Source20: kernel-%{kversion}-i586.config
Source21: kernel-%{kversion}-i586-smp.config
Source22: kernel-%{kversion}-i686.config
Source23: kernel-%{kversion}-i686-debug.config
Source24: kernel-%{kversion}-i686-smp.config
Source25: kernel-%{kversion}-i686-smp-debug.config
Source26: kernel-%{kversion}-i686-kdump.config

Source27: kernel-%{kversion}-x86_64.config
Source28: kernel-%{kversion}-x86_64-debug.config
Source29: kernel-%{kversion}-x86_64-kdump.config

Source30: kernel-%{kversion}-ppc.config
Source31: kernel-%{kversion}-ppc-smp.config
Source32: kernel-%{kversion}-ppc64.config
Source33: kernel-%{kversion}-ppc64iseries.config
Source34: kernel-%{kversion}-ppc64-kdump.config

Source35: kernel-%{kversion}-s390.config
Source36: kernel-%{kversion}-s390x.config

Source37: kernel-%{kversion}-ia64.config

Source38: kernel-%{kversion}-i686-xen0.config
Source39: kernel-%{kversion}-i686-xenU.config
Source40: kernel-%{kversion}-i686-xen.config
Source41: kernel-%{kversion}-x86_64-xen0.config
Source42: kernel-%{kversion}-x86_64-xenU.config
Source43: kernel-%{kversion}-x86_64-xen.config

#Source66: kernel-%{kversion}-sparc.config
#Source67: kernel-%{kversion}-sparc64.config
#Source68: kernel-%{kversion}-sparc64-smp.config

#
# Patches 0 through 100 are meant for core subsystem upgrades
#
Patch1: patch-2.6.20.1.bz2
Patch2: patch-2.6.20.1-2.bz2
Patch3: patch-2.6.20.2-3.bz2
Patch4: patch-2.6.20.3-4.bz2
Patch5: patch-2.6.20.4-5.bz2
Patch6: patch-2.6.20.5-6.bz2
Patch7: patch-2.6.20.6-7.bz2
Patch8: patch-2.6.20.7-8.bz2
Patch9: patch-2.6.20.8-9.bz2
Patch10: patch-2.6.20.9-10.bz2
Patch11: patch-2.6.20.10-11.bz2

# Patches 10 through 99 are for things that are going upstream really soon.

# enable sysrq-c on all kernels, not only kexec
Patch70: linux-2.6-sysrq-c.patch

# Patches 100 through 500 are meant for architecture patches

# 200 - 299   x86(-64)

Patch200: linux-2.6-x86-tune-generic.patch
Patch201: linux-2.6-x86-vga-vidfail.patch
Patch202: linux-2.6-x86-64-edac-support.patch
Patch203: linux-2.6-x86_64-silence-up-apic-errors.patch
Patch204: linux-2.6-x86-apic-auto.patch
Patch205: linux-2.6-x86_64_edac_update.patch
Patch206: linux-2.6-20_x86_64_xapic_8_bit_dest.patch
Patch207: linux-2.6.20-16kstacks.patch

# 300 - 399   ppc(64)
Patch301: linux-2.6-cell-mambo-drivers.patch
Patch302: linux-2.6-hvc-console.patch
Patch303: linux-2.6-ppc-rtas-check.patch
Patch310: linux-2.6-g5-therm-shutdown.patch
Patch311: linux-2.6-power6-no-ci-large-page.patch
Patch312: linux-2.6-mac-raid-autorun.patch

# 400 - 499   ia64

# 500 - 599   s390(x)

# 600 - 699   sparc(64)

#
# Patches 800 through 899 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#
Patch800: linux-2.6-build-nonintconfig.patch

# Exec-shield.
Patch810: linux-2.6-execshield.patch
Patch811: linux-2.6-warn-c-p-a.patch

# Module signing infrastructure.
Patch900: linux-2.6-modsign-mpilib.patch
Patch901: linux-2.6-modsign-crypto.patch
Patch902: linux-2.6-modsign-include.patch
Patch903: linux-2.6-modsign-verify.patch
Patch904: linux-2.6-modsign-ksign.patch
Patch905: linux-2.6-modsign-core.patch
Patch906: linux-2.6-modsign-script.patch

# Tux http accelerator.
Patch910: linux-2.6-tux.patch

# 950 - 999 Xen
Patch950: linux-2.6-xen.patch
Patch952: linux-2.6-xen-x86_64-silence-up-apic-errors.patch
Patch954: linux-2.6-xen-execshield.patch
Patch955: linux-2.6-xen-tux.patch
Patch961: linux-2.6-xen-pae-handle-64bit-addresses-correctly.patch
patch962: linux-2.6-xen-fixup-table-fix.patch
Patch963: linux-2.6-xen-pda-initialization.patch


#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#

Patch1010: linux-2.6-debug-sizeof-structs.patch
Patch1011: linux-2.6-debug-slab-backtrace.patch
Patch1013: linux-2.6-debug-taint-vm.patch
Patch1015: linux-2.6-debug-spinlock-taint.patch
Patch1016: linux-2.6-debug-Wundef.patch
Patch1018: linux-2.6-debug-sleep-in-irq-warning.patch
Patch1019: linux-2.6-debug-must_check.patch
Patch1020: linux-2.6-debug-no-quiet.patch
Patch1021: linux-2.6-debug-boot-delay.patch
Patch1022: linux-2.6-debug-sysfs-crash-debugging.patch
Patch1023: linux-2.6-debug-sysfs-crash-debugging-xen.patch

# Restrict /dev/mem usage.
Patch1050: linux-2.6-devmem.patch
Patch1051: linux-2.6-devmem-xen.patch

# Provide read only /dev/crash driver.
Patch1060: linux-2.6-crash-driver.patch
Patch1061: linux-2.6-crash-driver-xen.patch

Patch1070: linux-2.6-sleepon.patch

# SCSI bits.
Patch1106: linux-2.6-scsi-cpqarray-set-master.patch

# NFS bits.
Patch1201: linux-2.6-NFSD-badness.patch

# core networking changes.

# NIC driver fixes

# Filesystem stuff.
# Squashfs
Patch1400: linux-2.6-squashfs.patch

# GFS/DLM
Patch1410: linux-2.6-gfs2-update.patch
Patch1411: linux-2.6-gfs2-tux.patch
Patch1412: linux-2.6-gfs2-locking-exports.patch
Patch1413: linux-2.6-gfs2-update2.patch
Patch1414: linux-2.6-gfs2-update3.patch

# NFS superblock sharing / CacheFS
Patch1431: linux-2.6-cachefiles.patch

# Various NFS changes.

# Device mapper / MD layer

# Misc bits.
Patch1600: linux-2.6-module_version.patch
Patch1601: linux-2.6-sha_alignment.patch
Patch1650: linux-2.6-serial-460800.patch
Patch1681: linux-2.6-xfs-umount-fix.patch
Patch1682: linux-2.6-xfs_attr2.patch
Patch1690: linux-2.6-PT_LOAD-align.patch
Patch1720: linux-2.6-proc-self-maps-fix.patch
Patch1740: linux-2.6-softlockup-disable.patch
Patch1750: linux-2.6-usb-storage-reboot.patch
Patch1770: linux-2.6-optimise-spinlock-debug.patch
Patch1771: linux-2.6-silence-noise.patch
Patch1780: linux-2.6-drivers-add-qlogic-firmware.patch
Patch1781: linux-2.6-raid-autorun.patch
Patch1782: linux-2.6-drivers_pci_no_msi_mmconf.patch

# hold on to these
#Patch: linux-2.6-simplify_assign_irq_vector.patch
#Patch: linux-2.6-no_handler_for_vector_fix.patch

# 2.6.20 fixes for testing
Patch1790: linux-2.6-jfs_fix_deadlock.patch

# post 2.6.20.5
Patch1800: linux-2.6-20.5y-dm_crypt_disable_barriers.patch
Patch1802: linux-2.6-20.5z-mmap_dont_spam_logs.patch
Patch1805: linux-2.6-proposed-i82875p-edac-fix.patch
Patch1807: linux-2.6-20.7a-fib_rules_fix_return_value.patch
Patch1809: linux-2.6-21-rc6-readahead.patch
Patch1810: linux-2.6-i386_pci-add_debugging.patch

# post 2.6.20.11
Patch1830: linux-2.6-20.8b-x86_perfctr_fix_bitmap_sizing.patch
Patch1831: linux-2.6-20.8e-isdn-capi-disable-debug-messages.patch
Patch1832: linux-2.6-20.8f-oom_kill_all_threads_that_share_mm.patch
Patch1833: linux-2.6-20.8f-x86_64_always_flush_all_pages.patch
Patch1834: linux-2.6-20.8n-ipsec_fix_oops_with_large_context.patch
Patch1835: linux-2.6-20.8n-net_vlan_allow_with_bridge.patch
Patch1836: linux-2.6-20.8n-ppp_fix_skb_under_panic.patch
Patch1837: linux-2.6-page_is_ram.patch

Patch1841: linux-2.6-20.12b-input_i8042_fix_aux_port_detection_with_some_chips.patch

# SELinux/audit patches.
Patch1890: linux-2.6-selinux-mprotect-checks.patch

# Warn about usage of various obsolete functionality that may go away.
Patch1900: linux-2.6-obsolete-oss-warning.patch

# no external module should use these symbols.
Patch1910: linux-2.6-unexport-symbols.patch

# VM bits.
Patch2001: linux-2.6-vm-silence-atomic-alloc-failures.patch

# Tweak some defaults.
Patch2100: linux-2.6-defaults-fat-utf8.patch
Patch2101: linux-2.6-defaults-firmware-loader-timeout.patch
Patch2102: linux-2.6-defaults-phys-start.patch
Patch2103: linux-2.6-defaults-unicode-vt.patch
Patch2105: linux-2.6-defaults-nonmi.patch

# SATA Bits
Patch2200: linux-2.6-sata-promise-pata-ports.patch

# ACPI bits

#
# 10000 to 20000 is for stuff that has to come last due to the
# amount of drivers they touch. But only these should go here.
# Not patches you're too lazy for to put in the proper place.
#

Patch10000: linux-2.6-compile-fixes.patch

# Xen hypervisor patches (20000+)
Patch20000: xen-printf-rate-limit.patch
Patch20001: xen-version-strings.patch
Patch20002: xen-grant-security.patch
Patch20003: xen-amd-v-menu-timer-issue.patch
Patch20004: xen-pae-handle-64bit-addresses-correctly.patch
Patch20005: xen-fix-vcpu-hotplug-statistics.patch
Patch20007: xen-amd-v-hvm-fix-for-windows-hibernate.patch
Patch20008: xen-make-windows-vista-work.patch
Patch20011: xen-fix-swiotlb-for-b44-module-xen-patch.patch
Patch20012: xen-fix-for-smp-xen-guest-slow-boot-issue-on-amd-systems.patch
Patch20013: xen-hvm-crashes-on-ia32e-smp.patch
Patch20014: xen-make-ballooning-work-right.patch
Patch20015: xen-oprofile-on-intel-core.patch
Patch20016: xen-emulation-accesses-faulting-on-page-boundary.patch
Patch20018: xen-race-condition-concerning-vlapic-interrupts.patch
Patch20019: xen-emulate-pit-channels-for-vbios-support.patch
Patch20020: xen-greater-than-4g-guest-fix.patch
Patch20021: xen-make-hvm-hypercall-table-nr_hypercalls-entries-big.patch
Patch20022: xen-replace-inappropriate-domain_crash_synchronous-use.patch
Patch20023: xen-register-pit-handlers-to-the-correct-domain.patch
Patch20024: xen-quick-fix-for-cannot-allocate-memory.patch
Patch20025: xen-fix-tlb-flushing-in-shadow-pagetable-mode.patch
Patch20026: xen-enable-xen-booting-on-machines-with-64g.patch

Patch21008: linux-2.6-xen-fix-spinlock-when-removing-xennet-device.patch
Patch21011: linux-2.6-xen-privcmd-range-check-hypercall-index.patch
Patch21024: linux-2.6-xen-netback-reenable-tx-queueing.patch
Patch21027: linux-2.6-xen-avoid-touching-watchdog-when-gone-too-long.patch
Patch21036: linux-2.6-xen-iscsi-oops-on-x86_64-xen-domu.patch
Patch21038: linux-2.6-xen-make-netfront-device-permanent.patch
Patch21048: linux-2.6-xen-blkback-fix-first_sect-check.patch
Patch21056: linux-2.6-xen-fix-2tb-overflow-in-virtual-disk-driver.patch
Patch21059: linux-2.6-xen-netback-fix-transmit-credit-scheduler-wrap.patch
Patch21069: linux-2.6-xen-blkback-copy-shared-data-before-verification.patch
Patch21070: linux-2.6-xen-blkback-fix-potential-grant-entry-leaks-on-error.patch
Patch21081: linux-2.6-xen-properly-close-blkfront-on-non-existant-file.patch
Patch21087: linux-2.6-xen-copy-shared-data-before-verification.patch
Patch21104: linux-2.6-xen-fix-swiotlb-for-b44-module-kernel-patch.patch
Patch21112: linux-2.6-xen-make-ballooning-work-right.patch
Patch21147: linux-2.6-xen-fix-agp-on-x86_64-under-xen.patch
Patch21162: linux-2.6-xen-blktap-fix-potential-grant-entry-leaks-on-error.patch
Patch21165: linux-2.6-xen-use-swiotlb-mask-for-coherent-mappings-too.patch
Patch21188: linux-2.6-xen-fix-nosegneg-detection.patch
Patch21208: linux-2.6-xen-add-packet_auxdata-cmsg.patch

# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

%ifarch x86_64
Obsoletes: kernel-smp
%endif

%description
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%if 0%{?olpc}
Provides: kmod-sysprof = 1.0.3
%endif

%package devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel = %{rpmversion}-%{release}
Prereq: /usr/bin/find
%description devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.


%package smp
Summary: The Linux kernel compiled for SMP machines.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}smp
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
# upto and including kernel 2.4.9 rpms, the 4Gb+ kernel was called kernel-enterprise
# now that the smp kernel offers this capability, obsolete the old kernel
Obsoletes: kernel-enterprise < 2.4.10
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no
%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.

%package smp-devel
Summary: Development package for building kernel modules to match the SMP kernel.
Group: System Environment/Kernel
Provides: kernel-smp-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}smp
Provides: kernel-devel = %{rpmversion}-%{release}smp
AutoReqProv: no
Prereq: /usr/bin/find
%description smp-devel
This package provides kernel headers and makefiles sufficient to build modules
against the SMP kernel package.

%package smp-debug
Summary: The SMP Linux kernel compiled with extra debugging enabled.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}smp-debug
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
AutoReq: no
AutoProv: yes
%description smp-debug
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

%package smp-debug-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
Provides: kernel-smp-debug-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}smp-debug
Provides: kernel-devel = %{rpmversion}-%{release}smp-debug
AutoReqProv: no
Prereq: /usr/bin/find
%description smp-debug-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.


%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package debug
Summary: The Linux kernel compiled with extra debugging enabled.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}debug
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
AutoReq: no
AutoProv: yes
%description debug
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

%package debug-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
Provides: kernel-debug-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}debug
Provides: kernel-devel = %{rpmversion}-%{release}debug
AutoReqProv: no
Prereq: /usr/bin/find
%description debug-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.



%package xen0
Summary: The Linux kernel compiled for Xen guest0 VM operations
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}xen0
Prereq: %{kernel_prereq}
Requires: xen
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{xen_conflicts}
# the hypervisor kernel needs a newer mkinitrd than everything else right now
Conflicts: mkinitrd <= 4.2.0
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no
%description xen0
This package includes a version of the Linux kernel which
runs in Xen's guest0 VM and provides device services to
the unprivileged guests.

Install this package in your Xen guest0 environment.

%package xen0-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-xen0-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}xen0
Provides: kernel-devel = %{rpmversion}-%{release}xen0
Prereq: /usr/bin/find
%description xen0-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.


%package xen
Summary: The Linux kernel compiled for Xen VM operations with PAE support
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}xen
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{xen_conflicts}
# the xen kernel needs a newer mkinitrd than everything else right now
Conflicts: mkinitrd <= 4.2.0
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no
%description xen
This package includes a version of the Linux kernel which runs in
Xen's VM with PAE support and provides device services to the
unprivileged guests.

Install this package in your Xen guest0 environment.

%package xen-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-xen-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}xen
Provides: kernel-devel = %{rpmversion}-%{release}xen
Prereq: /usr/bin/find
%description xen-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.

%package xenU
Summary: The Linux kernel compiled for unprivileged Xen guest VMs
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}xenU
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{xen_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no
%description xenU
This package includes a version of the Linux kernel which
runs in Xen unprivileged guest VMs.  This should be installed
both inside the unprivileged guest (for the modules) and in
the guest0 domain.

%package xenU-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-xenU-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}xenU
Provides: kernel-devel = %{rpmversion}-%{release}xenU
Prereq: /usr/bin/find
%description xenU-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.


%package kdump
Summary: A minimal Linux kernel compiled for kernel crash dumps.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}kdump
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no
%description kdump
This package includes a kdump version of the Linux kernel. It is
required only on machines which will use the kexec-base kernel crash dump
mechanism.

%package kdump-devel
Summary: Development package for building kernel modules to match the kdump kernel.
Group: System Environment/Kernel
Provides: kernel-kdump-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}kdump
Provides: kernel-devel = %{rpmversion}-%{release}kdump
AutoReqProv: no
Prereq: /usr/bin/find
%description kdump-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kdump kernel package.

%prep
#if a rhel kernel, apply the rhel config options
%if 0%{?rhel}
  for i in %{all_arch_configs}
  do
    mv $i $i.tmp
    $RPM_SOURCE_DIR/merge.pl $RPM_SOURCE_DIR/config-rhel-generic $i.tmp > $i
    rm $i.tmp
  done
  for i in $RPM_SOURCE_DIR/kernel-%{kversion}-{i586,i686,i686-PAE,x86_64}*.config
  do
    echo i is this file  $i
    mv $i $i.tmp
    $RPM_SOURCE_DIR/merge.pl $RPM_SOURCE_DIR/config-rhel-x86-generic $i.tmp > $i
    rm $i.tmp
  done
%endif
#if a olpc kernel, apply the olpc config options
%if 0%{?olpc}
  for i in %{all_arch_configs}
  do
    mv $i $i.tmp
    $RPM_SOURCE_DIR/merge.pl $RPM_SOURCE_DIR/config-olpc-generic $i.tmp > $i
    rm $i.tmp
  done
%endif

# First we unpack the kernel tarball.
# If this isn't the first make prep, we use links to the existing clean tarball
# which speeds things up quite a bit.
if [ ! -d kernel-%{kversion}/vanilla ]; then
  # Ok, first time we do a make prep.
  rm -f pax_global_header
%setup -q -n %{name}-%{version} -c
  mv linux-%{kversion} vanilla
else
  # We already have a vanilla dir.
  cd kernel-%{kversion}
  if [ -d linux-%{kversion}.%{_target_cpu} ]; then
     # Just in case we ctrl-c'd a prep already
     rm -rf deleteme
     # Move away the stale away, and delete in background.
     mv linux-%{kversion}.%{_target_cpu} deleteme
     rm -rf deleteme &
  fi
fi
cp -rl vanilla linux-%{kversion}.%{_target_cpu}

cd linux-%{kversion}.%{_target_cpu}

# Update to latest upstream.
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1

# Patches 10 through 100 are meant for core subsystem upgrades

# sysrq works always
%patch70 -p1

# Architecture patches

#
# x86(-64)
#
# Compile 686 kernels tuned for Pentium4.
%patch200 -p1
# add vidfail capability;
# without this patch specifying a framebuffer on the kernel prompt would
# make the boot stop if there's no supported framebuffer device; this is bad
# for the installer cd that wants to automatically fall back to textmode
# in that case
%patch201 -p1
# EDAC support for K8
%patch202 -p1
# Suppress APIC errors on UP x86-64.
%patch203 -p1
# Use heuristics to determine whether to enable lapic on i386.
#%patch204 -p1
# K8 EDAC update for DDR2 and new CPUs
%patch205 -p1
# 8-bit dest field for xAPIC
%patch206 -p1
# 16K stacks
%patch207 -p1

#
# PowerPC
#
# Support the IBM Mambo simulator; core as well as disk and network drivers.
#%patch301 -p1
# Make HVC console generic; support simulator console device using it.
#%patch302 -p1
# Check properly for successful RTAS instantiation
%patch303 -p1
# Alleviate G5 thermal shutdown problems
%patch310 -p1
# Disable cache-inhibited 64KiB pages on POWER6
#%patch311 -p1

# S390

#
# Patches 800 through 899 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#


# This patch adds a "make nonint_oldconfig" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the buildsystem).
%patch800 -p1

# Exec shield
%patch810 -p1
#%patch811 -p1

#
# GPG signed kernel modules
#
%patch900 -p1
%patch901 -p1
%patch902 -p1
%patch903 -p1
%patch904 -p1
%patch905 -p1
%patch906 -p1

# Tux
#%patch910 -p1

#
# Xen
#
%if %{includexen}
#
# Apply the main xen patch...
#%patch951 -p1
%patch950 -p1 -b .p.xen
#
# ... and back out all the tpm additions, they need fixing
#
for f in `find drivers/char/tpm -type f -name "*.p.xen"` ; do \
    g=`dirname $f`/`basename $f .p.xen`; \
    mv "$f" "$g"; \
    if [ ! -s "$g" ] ; then rm -f "$g" ; fi; \
done
# Delete the rest of the backup files, they just confuse the build later
find -name "*.p.xen" | xargs rm -f

%patch952 -p1
# Xen exec-shield bits
%patch954 -p1
%patch955 -p1
%patch961 -p1
%patch962 -p1
%patch963 -p1
%endif

#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#


# Various low-impact patches to aid debugging.
%patch1010 -p1
%patch1011 -p1
%patch1013 -p1
%patch1015 -p1
%patch1016 -p1
%patch1018 -p1
%patch1019 -p1
# Disable the 'quiet' boot switch for better bug reports.
#%patch1020 -p1
%patch1021 -p1
%patch1022 -p1
%if %{includexen}
%patch1023 -p1
%endif

#
# Make /dev/mem a need-to-know function
#
%patch1050 -p1
%if %{includexen}
%patch1051 -p1
%endif

#
# /dev/crash driver for the crashdump analysis tool
#
%patch1060 -p1
%if %{includexen}
%patch1061 -p1
%endif

#
# Most^WAll users of sleep_on are broken; fix a bunch
#
%patch1070 -p1

#
# SCSI Bits.
#
# fix cpqarray pci enable
%patch1106 -p1

#
# Various NFS/NFSD fixes.
#
# Fix badness.
%patch1201 -p1

# core networking changes.

# NIC driver fixes

# Filesystem patches.
# Squashfs
%patch1400 -p1

# GFS2 fixes
%patch1410 -p1
# GFS2/DLM tux
#%patch1411 -p1
# GFS2/DLM locking exports
%patch1412 -p1
# additional gfs2 updates
%patch1413 -p1
%patch1414 -p1

#nfs sharing / cachefs
%patch1431 -p1

# NFS

# Device mapper / MD layer

# Misc fixes
# Add missing MODULE_VERSION tags to some modules.
%patch1600 -p1
# Fix SHA1 alignment problem on ia64
%patch1601 -p1
# Allow to use 480600 baud on 16C950 UARTs
%patch1650 -p1
# Fix XFS umount bug.
%patch1681 -p1
# Fix attr2 corruption with btree data extents
%patch1682 -p1
# Align kernel data segment to page boundary.
%patch1690 -p1
# setuid /proc/self/maps fix.
%patch1720 -p1
# Add a safety net to softlockup so that it doesn't prevent installs.
%patch1740 -p1
# USB storage not seen upon reboot
%patch1750 -p1
# Speed up spinlock debug.
%patch1770 -p1
# Silence some useless messages that still get printed with 'quiet'
%patch1771 -p1
# qlogic firmware
%patch1780 -p1
# restore START_ARRAY ioctl
%patch1781 -p1
# disable PCI MSI and MMCONFIG by default
%patch1782 -p1

# 2.6.20 test fixes
%patch1790 -p1

# post 2.6.20.6
%patch1800 -p1
%patch1802 -p1
%patch1805 -p1
%patch1807 -p1
%patch1809 -p1
%patch1810 -p1

# post 2.6.20.11
%patch1830 -p1
%patch1831 -p1
%patch1832 -p1
%patch1833 -p1
%patch1834 -p1
%patch1835 -p1
%patch1836 -p1
%patch1837 -p1

%patch1841 -p1

# Fix the SELinux mprotect checks on executable mappings
%patch1890 -p1

# Warn about obsolete functionality usage.
%patch1900 -p1
# Remove kernel-internal functionality that nothing external should use.
%patch1910 -p1

#
# VM related fixes.
#
# Silence GFP_ATOMIC failures.
%patch2001 -p1

# Changes to upstream defaults.
# Use UTF-8 by default on VFAT.
%patch2100 -p1
# Increase timeout on firmware loader.
%patch2101 -p1
# Change PHYSICAL_START
%patch2102 -p1

# Use unicode VT's by default.
%patch2103 -p1
# Disable NMI watchdog by default.
%patch2105 -p1

# ACPI patches

# SATA
# PATA ports on Promise.
%patch2200 -p1

#
# Patches 5000 to 6000 are reserved for new drivers that are about to
# be merged upstream
#

#
# final stuff
#

#
# misc small stuff to make things compile or otherwise improve performance
#
%patch10000 -p1

%patch21008 -p1
%patch21011 -p1
%patch21024 -p1
%patch21027 -p1
%patch21036 -p1
%patch21038 -p1
%patch21048 -p1
%patch21056 -p1
%patch21059 -p1
%patch21069 -p1
%patch21070 -p1
%patch21081 -p1
%patch21087 -p1
%patch21104 -p1
%patch21112 -p1
%patch21147 -p1
%patch21162 -p1
%patch21165 -p1
%patch21188 -p1
%patch21208 -p1

# END OF PATCH APPLICATIONS

cp %{SOURCE10} Documentation/

mkdir configs

cp -f %{all_arch_configs} .


%if 0%{?olpc}
# don't need these for OLPC
rm -f kernel-%{kversion}-*PAE*.config
rm -f kernel-%{kversion}-*xen*.config
rm -f kernel-%{kversion}-*kdump*.config
%endif

# now run oldconfig over all the config files
for i in *.config
do
  mv $i .config
  Arch=`head -1 .config | cut -b 3-`
  make ARCH=$Arch nonint_oldconfig > /dev/null
  echo "# $Arch" > configs/$i
  cat .config >> configs/$i
done

# make sure the kernel has the sublevel we know it has. This looks weird
# but for -pre and -rc versions we need it since we only want to use
# the higher version when the final kernel is released.
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -prep/" Makefile

# If we don't have many patches to apply, sometimes the deleteme
# trick still hasn't completed, and things go bang at this point
# when find traverses into directories that get deleted.
# So we serialise until the dir has gone away.
cd ..
while [ -d deleteme ];
do
	sleep 1
done

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null


# Unpack the Xen tarball.
%if %{includexen}
cp %{SOURCE2} .
if [ -d xen ]; then
  rm -rf xen
fi
%setup -D -T -q -n %{name}-%{version} -a1
cd xen
# Any necessary hypervisor patches go here
%patch20000 -p1
%patch20001 -p1
%patch20002 -p1
%patch20003 -p1
%patch20004 -p1
%patch20005 -p1
%patch20007 -p1
%patch20008 -p1
%patch20011 -p1
%patch20012 -p1
%patch20013 -p1
%patch20014 -p1
%patch20015 -p1
%patch20016 -p1
%patch20018 -p1
%patch20019 -p1
%patch20020 -p1
%patch20021 -p1
%patch20022 -p1
%patch20023 -p1
%patch20024 -p1
%patch20025 -p1
%patch20026 -p1

# Update the Makefile version strings
sed -i -e 's/\(^export XEN_BUILDER.*$\)/\1'%{?dist}'/' Makefile
sed -i -e 's/\(^export XEN_BUILDVERSION.*$\)/\1'-%{PACKAGE_RELEASE}'/' Makefile
%endif


###
### build
###
%build
#
# Create gpg keys for signing the modules
#

%if %{signmodules}
gpg --homedir . --batch --gen-key %{SOURCE11}
gpg --homedir . --export --keyring ./kernel.pub Red > extract.pub
make linux-%{kversion}.%{_target_cpu}/scripts/bin2c
linux-%{kversion}.%{_target_cpu}/scripts/bin2c ksign_def_public_key __initdata < extract.pub > linux-%{kversion}.%{_target_cpu}/crypto/signature/key.h
%endif

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3

    # Pick the right config file for the kernel we're building
    if [ -n "$Flavour" ] ; then
      Config=kernel-%{kversion}-%{_target_cpu}-$Flavour.config
      DevelDir=/usr/src/kernels/%{KVERREL}-$Flavour-%{_target_cpu}
      DevelLink=/usr/src/kernels/%{KVERREL}$Flavour-%{_target_cpu}
    else
      Config=kernel-%{kversion}-%{_target_cpu}.config
      DevelDir=/usr/src/kernels/%{KVERREL}-%{_target_cpu}
      DevelLink=
    fi

    KernelVer=%{version}-%{release}$Flavour
    echo BUILDING A KERNEL FOR $Flavour %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$Flavour/" Makefile

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    if [ "$KernelImage" == "x86" ]; then
       KernelImage=arch/$Arch/boot/bzImage
    fi

    make -s ARCH=$Arch nonint_oldconfig > /dev/null
    make -s ARCH=$Arch %{?_smp_mflags} $MakeTarget
    make -s ARCH=$Arch %{?_smp_mflags} modules || exit 1

    # Start installing the results

%if "%{_enable_debug_packages}" == "1"
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/boot
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/%{image_install_path}
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    touch $RPM_BUILD_ROOT/boot/initrd-$KernelVer.img
    cp $KernelImage $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer
    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi

    if [ "$Flavour" == "kdump" ]; then
        cp vmlinux $RPM_BUILD_ROOT/%{image_install_path}/vmlinux-$KernelVer
        rm -f $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer
    fi

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp arch/%{_arch}/kernel/asm-offsets.s $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/kernel || :
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/%{_arch}/scripts ]; then
      cp -a arch/%{_arch}/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/%{_arch}/*lds ]; then
      cp -a arch/%{_arch}/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a acpi config keys linux math-emu media mtd net pcmcia rdma rxrpc scsi sound video asm asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp -a `readlink asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    if [ "$Arch" = "x86_64" ]; then
      cp -a asm-i386 $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    fi
    # While arch/powerpc/include/asm is still a symlink to the old
    # include/asm-ppc{64,} directory, include that in kernel-devel too.
    if [ "$Arch" = "powerpc" -a -r ../arch/powerpc/include/asm ]; then
      cp -a `readlink ../arch/powerpc/include/asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
      mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/$Arch/include
      pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/$Arch/include
      ln -sf ../../../include/asm-ppc* asm
      popd
    fi
%if %{includexen}
    cp -a xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
%endif

    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf
    cd ..

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
%if "%{_enable_debug_packages}" == "1"
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # gpg sign the modules
%if %{signmodules}
    gcc -o scripts/modsign/mod-extract scripts/modsign/mod-extract.c -Wall
    KEYFLAGS="--no-default-keyring --homedir .."
    KEYFLAGS="$KEYFLAGS --secret-keyring ../kernel.sec"
    KEYFLAGS="$KEYFLAGS --keyring ../kernel.pub"
    export KEYFLAGS

    for i in `cat modnames`
    do
      sh ./scripts/modsign/modsign.sh $i Red
      mv -f $i.signed $i
    done
    unset KEYFLAGS
%endif
    # mark modules executable so that strip-to-file can strip them
    cat modnames | xargs chmod u+x

    # detect missing or incorrect license tags
    for i in `cat modnames`
    do
      echo -n "$i "
      /sbin/modinfo -l $i >> modinfo
    done
    cat modinfo |\
      grep -v "^GPL" |
      grep -v "^Dual BSD/GPL" |\
      grep -v "^Dual MPL/GPL" |\
      grep -v "^GPL and additional rights" |\
      grep -v "^GPL v2" && exit 1
    rm -f modinfo
    rm -f modnames
    # remove files that will be auto generated by depmod at rpm -i time
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf ../../..$DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    [ -z "$DevelLink" ] || ln -sf `basename $DevelDir` $RPM_BUILD_ROOT/$DevelLink
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

%if %{includexen}
%if %{buildxen}
  cd xen
  mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
# FixMe: Juan Quintela (when no PAE is not needed anymore)
  make debug=y verbose=y crash_debug=y pae=y
  install -m 644 xen.gz $RPM_BUILD_ROOT/boot/xen.gz-%{KVERREL}-PAE
  install -m 755 xen-syms $RPM_BUILD_ROOT/boot/xen-syms-%{KVERREL}-PAE
  make clean
  make debug=y verbose=y crash_debug=y
  install -m 644 xen.gz $RPM_BUILD_ROOT/boot/xen.gz-%{KVERREL}
  install -m 755 xen-syms $RPM_BUILD_ROOT/boot/xen-syms-%{KVERREL}
  cd ..
%endif
%endif

cd linux-%{kversion}.%{_target_cpu}

%if %{builddebug}
BuildKernel %make_target %kernel_image debug
%endif

%if %{buildup}
BuildKernel %make_target %kernel_image
%endif

%if %{buildsmp}
BuildKernel %make_target %kernel_image smp
%if %{builddebug}
BuildKernel %make_target %kernel_image smp-debug
%endif
%endif

%if %{includexen}
%if %{buildxen}
BuildKernel %xen_target %xen_image xen
BuildKernel %xen_target %xen_image xen0
BuildKernel %xen_target %xen_image xenU
%endif
%endif

%if %{buildkdump}
BuildKernel %make_target %kernel_image kdump
%endif

###
### install
###

%install

cd linux-%{kversion}.%{_target_cpu}

%if %{includexen}
%if %{buildxen}
mkdir -p $RPM_BUILD_ROOT/etc/ld.so.conf.d
rm -f $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
cat > $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf <<\EOF
# This directive teaches ldconfig to search in nosegneg subdirectories
# and cache the DSOs there with extra bit 0 set in their hwcap match
# fields.  In Xen guest kernels, the vDSO tells the dynamic linker to
# search in nosegneg subdirectories and to match this extra hwcap bit
# in the ld.so.cache file.
hwcap 0 nosegneg
EOF
chmod 444 $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
%endif
%endif

%if %{builddoc}
mkdir -p $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}/Documentation

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a+r *
# copy the source over
tar cf - Documentation | tar xf - -C $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}
%endif

%if %{buildheaders}
# Install kernel headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Manually go through the 'headers_check' process for every file, but
# don't die if it fails
chmod +x scripts/hdrcheck.sh
echo -e '*****\n*****\nHEADER EXPORT WARNINGS:\n*****' > hdrwarnings.txt
for FILE in `find $RPM_BUILD_ROOT/usr/include` ; do
    scripts/hdrcheck.sh $RPM_BUILD_ROOT/usr/include $FILE /dev/null >> hdrwarnings.txt || :
done
echo -e '*****\n*****' >> hdrwarnings.txt
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h
%endif
###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# load the loop module for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%pre
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%post
if [ `uname -i` == "x86_64" ]; then
  if [ -f /etc/sysconfig/kernel ]; then
    /bin/sed -i -e 's/^DEFAULTKERNEL=kernel-smp$/DEFAULTKERNEL=kernel/' /etc/sysconfig/kernel
  fi
fi
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade %{rpmversion}-%{release}
/sbin/new-kernel-pkg --package kernel --mkinitrd --depmod --install %{KVERREL}

%post devel
[ -f /etc/sysconfig/kernel ] && . /etc/sysconfig/kernel
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi

%post smp
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade %{rpmversion}-%{release}smp
/sbin/new-kernel-pkg --package kernel-smp --mkinitrd --depmod --install %{KVERREL}smp

%post smp-devel
[ -f /etc/sysconfig/kernel ] && . /etc/sysconfig/kernel
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-smp-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi

%post smp-debug
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade %{rpmversion}-%{release}smp-debug
/sbin/new-kernel-pkg --package kernel-smp-debug --mkinitrd --depmod --install %{KVERREL}smp-debug

%post xen0
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade %{rpmversion}-%{release}-xen0
/sbin/new-kernel-pkg --package kernel-xen0 --mkinitrd --depmod --install --multiboot=/boot/xen.gz-%{KVERREL} %{KVERREL}xen0
[ ! -x /sbin/ldconfig ] || /sbin/ldconfig -X

%post xen0-devel
[ -f /etc/sysconfig/kernel ] && . /etc/sysconfig/kernel
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-xen0-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi

%post xenU
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade %{rpmversion}-%{release}-xenU
/sbin/new-kernel-pkg --package kernel-xenU --mkinitrd --depmod --install %{KVERREL}xenU
[ ! -x /sbin/ldconfig ] || /sbin/ldconfig -X

%post xenU-devel
[ -f /etc/sysconfig/kernel ] && . /etc/sysconfig/kernel
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-xenU-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi

%post xen
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade %{rpmversion}-%{release}-xen
if [ -e /proc/xen/xsd_kva -o ! -d /proc/xen ]; then 
	/sbin/new-kernel-pkg --package kernel-xen --mkinitrd --depmod --install --multiboot=/boot/xen.gz-%{KVERREL}-PAE %{KVERREL}xen
else 
	/sbin/new-kernel-pkg --package kernel-xen --mkinitrd --depmod --install %{KVERREL}xen
fi
[ ! -x /sbin/ldconfig ] || /sbin/ldconfig -X

%post xen-devel
[ -f /etc/sysconfig/kernel ] && . /etc/sysconfig/kernel
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-xen-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi

%post kdump
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade %{rpmversion}-%{release}-kdump
/sbin/new-kernel-pkg --package kernel-kdump --mkinitrd --depmod --install %{KVERREL}kdump

%post kdump-devel
[ -f /etc/sysconfig/kernel ] && . /etc/sysconfig/kernel
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ] ; then
  pushd /usr/src/kernels/%{KVERREL}-kdump-%{_target_cpu} > /dev/null
  /usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
  popd > /dev/null
fi

%post debug
/sbin/new-kernel-pkg --package kernel-debug --mkinitrd --depmod --install %{KVERREL}debug || exit $?


%preun
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}

%preun smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp

%preun smp-debug
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp-debug

%preun kdump
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}kdump

%preun debug
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}debug || exit $?

%preun xen0
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}xen0

%preun xenU
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}xenU

%preun xen
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}xen


###
### file lists
###

%if %{buildup}

%files 
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/kernel
/lib/modules/%{KVERREL}/build
/lib/modules/%{KVERREL}/source
/lib/modules/%{KVERREL}/extra
/lib/modules/%{KVERREL}/updates
%ghost /boot/initrd-%{KVERREL}.img

%files devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-%{_target_cpu}

%if %{builddebug}

%files debug
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}debug
/boot/System.map-%{KVERREL}debug
/boot/config-%{KVERREL}debug
%dir /lib/modules/%{KVERREL}debug
/lib/modules/%{KVERREL}debug/kernel
/lib/modules/%{KVERREL}debug/build
/lib/modules/%{KVERREL}debug/source
/lib/modules/%{KVERREL}debug/extra
/lib/modules/%{KVERREL}debug/updates
%ghost /boot/initrd-%{KVERREL}debug.img

%files debug-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-debug-%{_target_cpu}
/usr/src/kernels/%{KVERREL}debug-%{_target_cpu}

%endif
#builddebug

%endif
# buildup

%if %{buildsmp}

%files smp
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
/boot/config-%{KVERREL}smp
%dir /lib/modules/%{KVERREL}smp
/lib/modules/%{KVERREL}smp/kernel
/lib/modules/%{KVERREL}smp/build
/lib/modules/%{KVERREL}smp/source
/lib/modules/%{KVERREL}smp/extra
/lib/modules/%{KVERREL}smp/updates
%ghost /boot/initrd-%{KVERREL}smp.img

%files smp-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-smp-%{_target_cpu}
/usr/src/kernels/%{KVERREL}smp-%{_target_cpu}

%if %{builddebug}

%files smp-debug
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}smp-debug
/boot/System.map-%{KVERREL}smp-debug
/boot/config-%{KVERREL}smp-debug
%dir /lib/modules/%{KVERREL}smp-debug
/lib/modules/%{KVERREL}smp-debug/kernel
/lib/modules/%{KVERREL}smp-debug/build
/lib/modules/%{KVERREL}smp-debug/source
/lib/modules/%{KVERREL}smp-debug/extra
/lib/modules/%{KVERREL}smp-debug/updates
%ghost /boot/initrd-%{KVERREL}smp-debug.img

%files smp-debug-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-smp-debug-%{_target_cpu}
/usr/src/kernels/%{KVERREL}smp-debug-%{_target_cpu}

%endif
# builddebug

%endif
# buildsmp

%if %{includexen}
%if %{buildxen}
%files xen0
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}xen0
/boot/System.map-%{KVERREL}xen0
/boot/config-%{KVERREL}xen0
/boot/xen.gz-%{KVERREL}
/boot/xen-syms-%{KVERREL}
%dir /lib/modules/%{KVERREL}xen0
/lib/modules/%{KVERREL}xen0/kernel
%verify(not mtime) /lib/modules/%{KVERREL}xen0/build
/lib/modules/%{KVERREL}xen0/source
/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
/lib/modules/%{KVERREL}xen0/extra
/lib/modules/%{KVERREL}xen0/updates
%ghost /boot/initrd-%{KVERREL}xen0.img

%files xen0-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-xen0-%{_target_cpu}
/usr/src/kernels/%{KVERREL}xen0-%{_target_cpu}

%files xenU
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}xenU
/boot/System.map-%{KVERREL}xenU
/boot/config-%{KVERREL}xenU
%dir /lib/modules/%{KVERREL}xenU
/lib/modules/%{KVERREL}xenU/kernel
%verify(not mtime) /lib/modules/%{KVERREL}xenU/build
/lib/modules/%{KVERREL}xenU/source
/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
/lib/modules/%{KVERREL}xenU/extra
/lib/modules/%{KVERREL}xenU/updates
%ghost /boot/initrd-%{KVERREL}xenU.img

%files xenU-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-xenU-%{_target_cpu}
/usr/src/kernels/%{KVERREL}xenU-%{_target_cpu}

%files xen
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}xen
/boot/System.map-%{KVERREL}xen
/boot/config-%{KVERREL}xen
/boot/xen.gz-%{KVERREL}-PAE
/boot/xen-syms-%{KVERREL}-PAE
%dir /lib/modules/%{KVERREL}xen
/lib/modules/%{KVERREL}xen/kernel
%verify(not mtime) /lib/modules/%{KVERREL}xen/build
/lib/modules/%{KVERREL}xen/source
/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
/lib/modules/%{KVERREL}xen/extra
/lib/modules/%{KVERREL}xen/updates
%ghost /boot/initrd-%{KVERREL}xen.img

%files xen-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-xen-%{_target_cpu}
/usr/src/kernels/%{KVERREL}xen-%{_target_cpu}

%endif
%endif

%if %{buildkdump}

%files kdump
%defattr(-,root,root)
/%{image_install_path}/vmlinux-%{KVERREL}kdump
/boot/System.map-%{KVERREL}kdump
/boot/config-%{KVERREL}kdump
%dir /lib/modules/%{KVERREL}kdump
/lib/modules/%{KVERREL}kdump/kernel
/lib/modules/%{KVERREL}kdump/build
/lib/modules/%{KVERREL}kdump/source
/lib/modules/%{KVERREL}kdump/extra
/lib/modules/%{KVERREL}kdump/updates
%ghost /boot/initrd-%{KVERREL}kdump.img

%files kdump-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-kdump-%{_target_cpu}
/usr/src/kernels/%{KVERREL}kdump-%{_target_cpu}
%endif

# only some architecture builds need kernel-doc

%if %{builddoc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{kversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{kversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{kversion}
%endif

%changelog
* Mon May 21 2007 Chuck Ebbert <cebbert@redhat.com>		1.2319
- Fix i8042 mouse port detection for some chipsets

* Mon May 21 2007 Eduardo Habkost <ehabkost@redhat.com>		1.2318
- Xen kernel: added patch from Stephen C. Tweedie. Fix crashes and
  hangs, by making critical_fixup_table correct. Fixes bug #235188
- Xen kernel: added patch to initialize pda properly on smp_prepare_cpus()

* Tue May 05 2007 Chuck Ebbert <cebbert@redhat.com>		1.2317
- 2.6.20.10 (official)
- 2.6.20.11
- Additional fixes (1830 - 1837)

* Fri Apr 27 2007 Chuck Ebbert <cebbert@redhat.com>		1.2316
- 2.6.20.10 (from mailing list)

* Thu Apr 26 2007 Chuck Ebbert <cebbert@redhat.com>		1.2315
- 2.6.20.8 (official)
- 2.6.20.9

* Wed Apr 25 2007 Chuck Ebbert <cebbert@redhat.com>		1.2314
- 2.6.20.8
  Patch taken from mailing list, not available elsewhere.

* Tue Apr 17 2007 Chuck Ebbert <cebbert@redhat.com>		1.2313
- 2.6.20.7

* Tue Apr 10 2007 Chuck Ebbert <cebbert@redhat.com>		1.2312
- 2.6.20.5
- 2.6.20.6
- GFS2 update (1414)
- additional bugfixes (1806-1813)

* Wed Apr  4 2007 Chuck Ebbert <cebbert@redhat.com>		1.2311
- 2.6.20.5-rc1 plus two fixes for broken -rc1 patches.
- additional post 2.6.20.5 patches (1800-1805)

* Wed Apr  4 2007 Markus Armbruster <armbru@redhat.com>
- Xen kernel profiling fix is broken, back it out.

* Tue Apr  3 2007 Chuck Ebbert <cebbert@redhat.com>		1.2309
- 2.6.20.4 final.
- Add Marvell PATA driver.
- 1782: Disable PCI MSI and MMCONFIG by default,
  add options to enable them.
- 1413: GFS2 update.

* Tue Apr  3 2007 Markus Armbruster <armbru@redhat.com>
- Add PACKET_AUXDATA cmsg (Herbert Xu )
- Xen kernel:
  >4G guest fix (Steven Rostedt )
  fix nosegneg detection (Rik van Riel )
  Use swiotlb mask for coherent mappings too (Herbert Xu )
  Fix potential grant entry leaks on error (Herbert Xu )
  Fix agp on x86_64 under Xen (Stephen C. Tweedie )
  netback: Reenable TX queueing and drop pkts after timeout (Herbert Xu )
  make ballooning work right (Rik van Riel )
  Fix xen swiotlb for b44 module (Stephen C. Tweedie )
  Copy shared data before verification (Herbert Xu )
  Properly close block frontend on non-existant file (Glauber de Oliveira Costa )
  blkback: Fix potential grant entry leaks on error (Rik van Riel )
  blkback: Copy shared data before verification (Rik van Riel)
  netback: Fix wrap to zero in transmit credit scheduler. (Herbert Xu )
  fix 2TB overflow in virtual disk driver (Rik van Riel )
  blkback: Fix first_sect check. (Rik van Riel )
  make netfront device permanent (Glauber de Oliveira Costa )
  fix iSCSI root oops on x86_64 xen domU (Rik van Riel )
  Avoid touching the watchdog when gone for too long (Glauber de Oliveira Costa )
  fix profiling (Rik van Riel )
  privcmd: Range-check hypercall index. (Herbert Xu )
  Fix spinlock bad magic when removing xennet device (Chris Lalancette )
- Xen hypervisor:
  Enable Xen booting on machines with > 64G (Chris Lalancette )
  fix TLB flushing in shadow pagetable mode (Rik van Riel )
  quick fix for Cannot allocate memory (Steven Rostedt )
  Register PIT handlers to the correct domain (Herbert Xu )
  Replace inappropriate domain_crash_synchronous use (Herbert Xu )
  Make HVM hypercall table NR_hypercalls entries big. (Herbert Xu )
  >4G guest fix (Steven Rostedt )
  emulate PIT channels for vbios support (Stephen C. Tweedie )
  Race condition concerning VLAPIC interrupts (Bhavana Nagendra )
  emulation for accesses faulting on a page boundary (Stephen C. Tweedie )
  oprofile on Intel CORE (Glauber de Oliveira Costa )
  make ballooning work right (xen part) (Rik van Riel )
  HVM crashes on IA32e SMP (Glauber de Oliveira Costa )
  Fix for SMP Xen guest slow boot issue on AMD systems (Bhavana Nagendra )
  Fix xen swiotlb for b44 module (xen part) (Stephen C. Tweedie )
  upstream patches to make Windows Vista work (Steven Rostedt)
  AMD-V HVM fix for Windows hibernate (Bhavana Nagendra )
  fix vcpu hotplug statistics (Rik van Riel )
  xen pae >4GB patch (Don Zickus)
  AMD-V HVM windows guest boot menu timer issue (Steven Rostedt)

* Sun Mar 18 2007 Chuck Ebbert <cebbert@redhat.com>
- fixed typo in Xen patch
- 2.6.20.4 queue (24 patches)
- removed (now in 20.4 queue):
	1806: linux-2.6-20_hrtimer_prevent_dos.patch
	1807: linux-2.6-20_nfs_getattr_check_isreg.patch
	1808: linux-2.6-20_pi_futex_state_locking.patch
	1794: linux-2.6-20_ia64_chip_mask.patch (Prarit)

* Fri Mar 16 2007 Dave Jones <davej@redhat.com>
- Add driver for USB EHCI debug cables.

* Fri Mar 16 2007 Chuck Ebbert <cebbert@redhat.com>
- new version of patch for BZ #232600: 
	2200: linux-2.6-sata-promise-pata-ports.patch
- added:
	1800: linux-2.6-20.4-adjust-legacy-ide-resource-setting.patch
	1801: linux-2.6-20.4-fix-another-null-deref-in-ipv6.patch
	1802: linux-2.6-20.4-fix-rtm_to_ifaddr-error-return.patch
	1803: linux-2.6-20.4-netlabel-cipso_std_bug.patch
	1804: linux-2.6-20.4-nfnetlink_log-refcounting.patch
	1805: linux-2.6-20.4-SCSI-gdth-fix-oops.patch
	1806: linux-2.6-20_hrtimer_prevent_dos.patch
	1807: linux-2.6-20_nfs_getattr_check_isreg.patch
	1808: linux-2.6-20_pi_futex_state_locking.patch

* Thu Mar 15 2007 Chuck Ebbert <cebbert@redhat.com>
- Added:
	206: linux-2.6-20_x86_64_xapic_8_bit_dest.patch

* Wed Mar 14 2007 Juan Quintela <quintela@redhat.com>
- make brew happy with new changeset.

* Wed Mar 14 2007 Juan Quintela <quintela@redhat.com>
- Enable xen again & update all the xen patches to 2.6.20.2.

* Tue Mar 13 2007 Chuck Ebbert <cebbert@redhat.com>
- 2.6.20.3
- added
	205: linux-2.6-x86_64_edac_update.patch

* Sun Mar 11 2007 Chuck Ebbert <cebbert@redhat.com>
- 2.6.20.2
- 2.6.20.3-rc1
- removed (now in -stable):
	1787: linux-2.6-net_bcm43xx_1GB_DMA_fix.patch
	1792: linux-2.6-cardman_buffer_overflow.patch (CVE-2007-0005)
	1793: linux-2.6-nf_conntrack_fix_cleanup.patch
	1794: linux-2.6-x86_64_survive_no_irq_for_vector.patch
- updated
	linux-2.6-gfs2-update.patch (Steve Whitehouse)
- added
	1792: linux-2.6-20_git-serio-keyboard.patch
	1794: linux-2.6-20_ia64_chip_mask.patch (Prarit)

* Wed Mar 7 2007 Chuck Ebbert <cebbert@redhat.com>
- 2.6.20.2-rc1
- Additional fixes:
	1787: linux-2.6-net_bcm43xx_1GB_DMA_fix.patch
	1790: linux-2.6-jfs_fix_deadlock.patch
	1791: linux-2.6-git-serio-1e4865f8d469b1.patch
	1792: linux-2.6-cardman_buffer_overflow.patch (CVE-2007-0005)
	1793: linux-2.6-nf_conntrack_fix_cleanup.patch
	1794: linux-2.6-x86_64_survive_no_irq_for_vector.patch
 
* Thu Feb 22 2007 Dave Jones <davej@redhat.com>
- Drop verbose BUG() debug patch

* Tue Feb 20 2007 Dave Jones <davej@redhat.com>
- restore START_ARRAY ioctl.

* Tue Feb 20 2007 Chuck Ebbert <cebbert@redhat.com>
- Add patch 2.6.20.1 (CVE-2007-0772)
- Bugfixes (including those from Feb 18)
  (NOTE: These may have been reported on FC6)
	two patches for "No handler for vector" (BZ #225399)
	usbnet oops (BZ #228231)
	hda_intel no sound with si3054 codec (BZ #228879)
	two iee1394 fixes 
	swiotlb bugfix
	two raid5/raid6 bugfixes
	jfs deadlock fix
	net xfrm audit log oops fix
	Bcm43xx 30-bit DMA fix (BZ #213556)
	disable MSI in the forcedeth driver

* Sun Feb 18 2007 Chuck Ebbert <cebbert@redhat.com>
- add 2.6.20 fixes

* Thu Feb 15 2007 Chuck Ebbert <cebbert@redhat.com>
- rebase to linux kernel 2.6.20

* Sat Feb 10 2007 Chuck Ebbert <cebbert@redhat.com>
- add missing "provides" for debug-devel packages
- clean up some other "provides" things
- add fixes for RHBZ#211672 (CIFS) and RHBZ#227802 (8139too)

* Wed Feb 7 2007 Chuck Ebbert <cebbert@redhat.com>
- add missing debug-devel and smp-debug-devel sections

* Wed Feb 7 2007 Chuck Ebbert <cebbert@redhat.com>
- fix up x86_64 Xen build

* Tue Feb 6 2007 Chuck Ebbert <cebbert@redhat.com>
- disable Tux
- add another GFS2 update
- add crypto key collision patch (CVE-2007-0006)

* Mon Feb 5 2007 Dave Jones <davej@redhat.com>
- Reenable Tux.

* Mon Feb 5 2007 Chuck Ebbert <cebbert@redhat.com>
- 2.6.19.3
- updated mirrors: refer to ftp2.kernel.org until
  kernel.org problems are fixed

* Sun Feb 4 2007 Dave Jones <davej@redhat.com>
- 2.6.19.3rc1

* Sat Feb 3 2007 Dave Jones <davej@redhat.com>
- Disable kdump options in non-kdump kernels.

* Thu Feb 1 2007 Chuck Ebbert <cebbert@redhat.com>
- Added i586 optimized AES and Blowfish modules to the i686 config
- Fixed .cvsignore

* Wed Jan 31 2007 Markus Armbruster <armbru@redhat.com>
- The previous cset folded the Xen paravirt framebuffer patch into
  linux-2.6-xen.patch, and commented out the obsoleted patch files.
  Remove them.

* Wed Jan 31 2007 Chuck Ebbert <cebbert@redhat.com>
- Update to 2.6.19.2

* Tue Jan 30 2007 Markus Armbruster <armbru@redhat.com>
- Update Xen paravirt framebuffer patch to upstream xen-unstable
  changeset 13066, less changeset 12680, because that breaks with
  console=tty console=xvc.  Also change default domU console back to
  /dev/xcv0.  This changes the protocol to the one accepted upstream.
- Add compatibility with guests running our initial protocol.
- Update Xen console major/minor to lanana.org-assigned numbers.

* Wed Dec 20 2006 Dave Jones <davej@redhat.com>
- Update to 2.6.18.6 final (no changes since rc2)
- Reenable squashfs (#220293)

* Fri Dec 15 2006 Dave Jones <davej@redhat.com>
- 2.6.18.6rc2

* Wed Dec 13 2006 Dave Jones <davej@redhat.com>
- squashfs robustness fixes from Phillip Lougher.
- lower max CPU count for x86-64 to 64 CPUs.

* Thu Dec  7 2006 Juan Quintela <quintela@redhat.com>
- update xen to 2.6.18.5.
- Fix bug 211986 on xen eventchn (Glaubert).

* Tue Dec  5 2006 Dave Jones <davej@redhat.com>
- 2.6.18.5
- Disable auto-apic patch, it needs more thought.
- Enable sonypi driver for 586 kernels. (#218434)

* Tue Nov 21 2006 Juan Quintela <quintela@redhat.com>
- Update xen to 2.6.18.3.
  * linux-2.6.18-xen changeset:   36186:053cdad40903
  * xen-3.0.3-testing changeset:   11774:52ae8dd4bc75
  * linux-2.6-xen-3.0.3 changeset:   22949:4281f5246814

* Mon Nov 20 2006 Dave Jones <davej@redhat.com>
- 2.6.18.3
- Fix CIFS mount failure when domain not specified (#211753)
- Avoid null pointer dereference in SATA Promise. (#199142)

* Fri Nov 17 2006 Dave Jones <davej@redhat.com>
- Fix up fallout from disabling utrace.

* Fri Nov 17 2006 Juan Quintela <quintela@redhat.com>
- merge xen missing bits from FC6 kernel.

* Thu Nov 16 2006 Dave Jones <davej@redhat.com>
- Fix up error handling in HFS. (MOKB-14-11-2006)

* Thu Nov 16 2006 Juan Quintela <quintela@redhat.com>
- Update xen HV to 3.0.3_0 (cset 11774).
- Update xen kernel patch to 3.0.3_0:
  * linux-2.6.18-xen changeset:   36182:c6ef4b521aef
  * xen-3.0.3-testing changeset:   11774:52ae8dd4bc75
  * linux-2.6-xen-3.0.3 changeset:   22949:4281f5246814

* Thu Nov 16 2006 Dave Jones <davej@redhat.com>
- Fix squashfs corruption bug. (#211237)
- Drop experimental utrace from FC5.

* Fri Nov 10 2006 Juan Quintela <quintela@redhat.com>
- disable XEN_FRAMEBUFFER & XEN_KEYBOARD.

* Fri Nov 10 2006 Dave Jones <davej@redhat.com>
- Xen grant table operations security fix.
- Disable W1 (#195825)

* Thu Nov  9 2006 Dave Jones <davej@redhat.com>
- Change HZ to 1000 for increased accuracy.
  (Except in Xen, where it stays at 250 for now).
- TTY locking fixes.
- splice : Must fully check for FIFO
- Fix potential NULL dereference in sys_move_pages
- ISO9660 __find_get_block_slow() denial of service CVE-2006-5757
- Fix up oops in cramfs when encountering corrupt images.
- E1000 suspend/resume fixes.
- Set CIFS preferred IO size. (#214607)

* Mon Nov  6 2006 Roland McGrath <roland@redhat.com>
- New utrace patch: fix locking snafu crash on second engine attach.

* Sun Nov  5 2006 Dave Jones <davej@redhat.com>
- Suspend/Resume fixes for forcedeth. (#187653)

* Sat Nov  4 2006 Dave Jones <davej@redhat.com>
- 2.6.18.2

* Thu Nov  2 2006 Dave Jones <davej@redhat.com>
- Nuke broken lazy execshield xen patch.
- Use heuristics to determine whether to enable lapic on i386.

* Wed Nov  1 2006 Dave Jones <davej@redhat.com>
- 2.6.18.2-rc1

* Tue Oct 31 2006 Dave Jones <davej@redhat.com>
- Fix UFS mounts on x86-64 (#209921)
- Fix problem where USB storage isn't seen on reboot. (#212191)

* Sun Oct 29 2006 Dave Jones <davej@redhat.com>
- More ext3 robustness fixes.
- Include more verbose BUG() data
- x86_64: Fix up C3 timer latency.

* Sat Oct 21 2006 Dave Jones <davej@redhat.com>
- Reenable NCPFS (#211325, #203663)
- Netpoll fixes. (#199295)

* Fri Oct 20 2006 Dave Jones <davej@redhat.com>
- Fix autofs creating bad dentries in NFS mount. (#211206, #211207)
- Fix softlockup with ips driver. (#196437)
- Further exec-shield improvements.
- Fix lockup with sky2 driver. (#202203)

* Thu Oct 19 2006 Dave Jones <davej@redhat.com>
- Export copy_4K_page for ppc64 (#211410)
- Attempt to fix CIFS bug (#211070)

* Wed Oct 18 2006 Dave Jones <davej@redhat.com>
- Fix up aic7xxx SBLKCTL register handling (#211251)
- Disable SECMARK by default. (#211115)
- Disable some extra debugging stuff that crept in.
- Remove broken VIA quirk that prevented booting on some EPIAs (#211298)

* Tue Oct 17 2006 Dave Jones <davej@redhat.com>
- Silence noisy boot-time messages. (#180606)
- Workaround gcc bug with weak symbols (#191458)
- Don't let speedstep-smi register on mobile Pentium4 (#204477)

* Sat Oct 14 2006 Dave Jones <davej@redhat.com>
- Fix jbd crash with 1KB block size filesystems.

* Sat Oct 14 2006 Dave Jones <davej@redhat.com> [2.6.18-1.2200.fc5]
- 2.6.18.1

* Tue Oct 10 2006 Dave Jones <davej@redhat.com>
- DWARF2 unwinder fixes.
- Various lockdep fixes.
- Sync various other patches from the FC6 kernel.

* Sun Oct  1 2006 Dave Jones <davej@redhat.com>
- Drop the STICKY tag from acpi-cpufreq, it breaks suspend/resume.

* Fri Sep 29 2006 Dave Jones <davej@redhat.com>
- Execshield improvements. (Bart Oldeman)
- Disable PM_DEBUG

* Thu Sep 28 2006 Roland McGrath <roland@redhat.com>
- utrace typo fix for x86-64 watchpoints (#207467)

* Thu Sep 28 2006 Dave Jones <davej@redhat.com>
- Fix ISAPNP messages on ppc32. (#207641)

* Thu Sep 28 2006 Dave Jones <davej@redhat.com>
- Another day, another round of lockdep fixes.
- Align kernel data segment to page boundary. (#206863)

* Thu Sep 28 2006 Steven Whitehouse <swhiteho@redhat.com>
- New GFS2 patch

* Thu Sep 28 2006 Dave Jones <davej@redhat.com>
- Fix "kernel BUG at fs/buffer.c:2789!" bug

* Wed Sep 27 2006 Dave Jones <davej@redhat.com>
- yet more lockdep fixes.
- Fix a problem with XFS & the inode diet patches.
- Fix rpc_pipefs umount oops
- Enable alternative TCP congestion algorithms.

* Tue Sep 26 2006 Dave Jones <davej@redhat.com>
- Enable serverworks IDE driver for x86-64.
- More lockdep fixes.

* Mon Sep 25 2006 Jarod Wilson <jwilson@redhat.com>
- Make kernel packages own initrd files

* Mon Sep 25 2006 John W. Linville <linville@redhat.com>
- Add periodic work fix for bcm43xx driver

* Sat Sep 23 2006 Dave Jones <davej@redhat.com>
- Disable dgrs driver.

* Thu Sep 21 2006 Dave Jones <davej@redhat.com>
- reiserfs: make sure all dentry refs are released before
  calling kill_block_super
- Fix up some compile warnings

* Thu Sep 21 2006 Juan Quintela <quintela@redhat.com>
- re-enable xen.
- update xen:
  * linux-2.6 changeset:   34294:dc1d277d06e0
  * linux-2.6-xen-fedora changeset:   36184:47c098fdce14
  * xen-unstable changeset:   11540:9837ff37e354
- update xen HV to changeset:   11540:9837ff37e354
- xen HV printf rate limit (rostedt).

* Wed Sep 20 2006 Dave Jones <davej@redhat.com>
- 2.6.18
- i965 AGP suspend support.
- AGP x8 fixes.

* Tue Sep 19 2006 Juan Quintela <quintela@redhat.com>
- updated xen configs to sync with rawhide ones (don't be afraid, xen0/xenU
  still around).
- xen update.
 * linux-2.6 changeset: 34228:ea3369ba1e2c
 * linux-2.6-xen-fedora changeset: 36109:eefcfd07d102
 * linux-2.6-xen changeset: 22905:d8ae02f7df05
 * xen-unstable changeset: 11460:1ece34466781ec55f41fd29d53f6dafd208ba2fa

* Mon Sep 18 2006 Dave Jones <davej@redhat.com>
- Bring back 586smp
- Fix RTC lockdep bug. (Peter Zijlstra)

* Mon Sep 18 2006 Juan Quintela <quintela@redhat.com>
- xen HV update (cset 11470:2b8dc69744e3).

* Sun Sep 17 2006 Juan Quintela <quintela@redhat.com>
- xen update:
  * linux-2.6 changeset: 34228:ea3369ba1e2c
  * linux-2.6-xen-fedora changeset: 36107:47256dbb1583
  * linux-2.6-xen changeset: 22905:d8ae02f7df05
  * xen-unstable changeset: 11460:1ece34466781ec55f41fd29d53f6dafd208ba2fa

* Sun Sep 17 2006 Dave Jones <davej@redhat.com>
- Rebase to 2.6.18rc7-git2

* Mon Sep 11 2006 Dave Jones <davej@redhat.com> [2.6.17-1.2187_FC5]
- Add quirk for Samsung mp3 player. (#198128)

* Sun Sep 10 2006 Dave Jones <davej@redhat.com>
- Fix up mismerge in USB storage driver.

* Sat Sep  9 2006 Dave Jones <davej@redhat.com>
- 2.6.17.13

* Fri Sep  8 2006 Dave Jones <davej@redhat.com>
- 2.6.17.12

* Thu Aug 24 2006 Jarod Wilson <jwilson@redhat.com>
- update to 2.6.17.11

* Tue Aug 22 2006 Bill Nottingham <notting@redhat.com>
- update to 2.6.17.10«

* Tue Aug 15 2006 Juan Quintela <quintela@redhat.com>
- linux-2.6-xen update
  * linux-2.6.17-xen cset changeset: 29033:e6adb54afb96
  * linux-2.6-xen cset 22813:80c2ccf5c330
- s/xen_version/xen_hv_cset/ as Fedora.
- update xen hv to cset 11061.

* Mon Aug  7 2006 Mike Christie <mchristi@redhat.com>
- Drop iscsi update patch.

* Mon Aug  7 2006 Dave Jones <davej@redhat.com>
- 2.6.17.8

* Fri Aug  4 2006 Dave Jones <davej@redhat.com>
- Fix split lock patch for 64bit.

* Fri Aug  4 2006 Dave Jones <davej@redhat.com> [2.6.17-1.2171_FC5]
- 2.6.17.8rc1

* Wed Aug  2 2006 Dave Jones <davej@redhat.com>
- Readd patch to allow 460800 baud on 16C950 UARTs

* Sat Jul 29 2006 Dave Jones <davej@redhat.com>
- Silence noisy SCSI ioctl. (#200638)

* Fri Jul 28 2006 Dave Jones <davej@redhat.com>
- 2.6.17.7

* Thu Jul 27 2006 Rik van Riel <riel@redhat.com>
- reduce hypervisor stack use with -O2, this really fixes bug (#198932)

* Tue Jul 25 2006 Rik van Riel <riel@redhat.com>
- disable debug=y hypervisor build option because of stack overflow (#198932)

* Tue Jul 25 2006 Dave Jones <davej@redhat.com>
- Enable serio_raw (#199387)

* Sun Jul 16 2006 Dave Jones <davej@redhat.com>
- Support up to 4GB in the 586 kernel again.

* Sat Jul 16 2006 Dave Jones <davej@redhat.com>
- 2.6.17.6

* Fri Jul 14 2006 Dave Jones <davej@redhat.com>
- Reenable SMC NIC driver.

* Tue Jul 11 2006 Dave Jones <davej@redhat.com>
- 2.6.17.4
- Disable split pagetable lock

* Sat Jul  8 2006 Juan Quintela <quintela@redhat.com>
- enable CONFIG_CRASH on xen kernels.
- enable CONFIG_PCIDEV_BACKEND on xen kernels.
- make BLKDEV_FRONTEND a module on xen kernels.
- rebase with linux-2.6-xen-fedora 28918.
- Update to xen-unstable HV cset 10508.
- xen: credit scheduler is the default now.

* Wed Jul  5 2006 Dave Jones <davej@redhat.com>
- Get rid of stack backtrace on panic, which in most
  cases actually caused a loss of info instead of a gain.

* Tue Jul  4 2006 Juan Quintela <quintela@redhat.com>
- new merge with xen upstream.
- xen kernel don't require xen userland.
- new xen kernel (same as rawhide one) with PAE support.
- removed xen0-PAE & xenU-PAE (see xen kernel).

* Fri Jun 30 2006 Dave Jones <davej@redhat.com>
- 2.6.17.3
- 2.6.17.2
- Fix the ALSA list_add bug.

* Mon Jun 26 2006 Dave Jones <davej@redhat.com>
- Enable fake PCI hotplug driver. (#190437)
- Enable gameport/joystick on i586 builds. (#196581)

* Sat Jun 24 2006 Dave Jones <davej@redhat.com>
- Enable profiling for 586 kernels.

* Fri Jun 23 2006 Dave Jones <davej@redhat.com>
- Make 'quiet' work again.

* Tue Jun 20 2006 Dave Jones <davej@redhat.com> [2.6.17-1.2139_FC5]
- Rebuild with slab debug off.

* Tue Jun 20 2006 Dave Jones <davej@redhat.com> [2.6.17-1.2138_FC5]
- 2.6.17.1

* Sun Jun 18 2006 Dave Jones <davej@redhat.com>
- 2.6.17
- Only print info about SMP alternatives on SMP kernels.

* Tue Jun  6 2006 Dave Jones <davej@redhat.com> [2.6.16-1.2133_FC5]
- Add a PPC64 kdump kernel.

* Mon Jun  5 2006 Dave Jones <davej@redhat.com> [2.6.16-1.2132_FC5]
- 2.6.16.20

* Thu Jun  1 2006 Dave Jones <davej@redhat.com>
- Reenable Xen builds.

* Tue May 30 2006 Dave Jones <davej@redhat.com>
- 2.6.16.19

* Sun May 28 2006 Dave Jones <davej@redhat.com>
- Fix unresolved symbol. (#193333)

* Sat May 27 2006 Dave Jones <davej@redhat.com>
- Improve list corruption debugging patch.

* Fri May 26 2006 Dave Jones <davej@redhat.com>
- Remove xenU initrd's when kernel is removed.

* Fri May 26 2006 Juan Quintela <quintela@redhat.com>
- Remove ARCH=xen reminiscences on spec file

* Sun May 21 2006 Dave Jones <davej@redhat.com> [2.6.16-1.2123_FC5]
- 2.6.16.18

* Sun May 21 2006 Dave Jones <davej@redhat.com> [2.6.16-1.2122_FC5]
- Remove noisy 'syscall not implemented' message from x86-64.

* Sun May 21 2006 David Woodhouse <dwmw2@redhat.com> [2.6.16-1.2120_FC5]
- Avoid thermal shutdown on some G5 machines.
- Make i386 two-minute delay on oops optional (oopsdelay= option)

* Sat May 20 2006 Dave Jones <davej@redhat.com> [2.6.16-1.2119_FC5]
- 2.6.16.17

* Thu May 11 2006 Juan Quintela <quintela@redhat.com> [2.6.16-1.2118_FC5]
- merge with 3.0.2 xen (cset 9668)
- add xen hypervisor to match it

* Wed May 10 2006 Dave Jones <davej@redhat.com>
- 2.6.16.16

* Tue May  9 2006 Dave Jones <davej@redhat.com>
- 2.6.16.15
- Fix exec-shield default, which should fix a few programs that
  stopped running.

* Sat May  6 2006 Dave Jones <davej@redhat.com>
- Enable ATM in 586 kernels (#190202)

* Thu May  4 2006 Dave Jones <davej@redhat.com> [2.6.16-1.2111_FC5]
- 2.6.16.14
- Revert broken Xen update that sneaked into the last update.

* Wed May  3 2006 Dave Jones <davej@redhat.com>
- disable MSI until 2.6.17.

* Tue May  2 2006 Dave Jones <davej@redhat.com> [2.6.16-1.2107_FC5]
- 2.6.16.13

* Mon May  1 2006 Dave Jones <davej@redhat.com>
- 2.6.16.12

* Tue Apr 25 2006 David Woodhouse <dwmw2@redhat.com>
- Use check_legacy_ioport() even on 32-bit PPC kernel

* Tue Apr 25 2006 Dave Jones <davej@redhat.com>
- Enable DVB in the 586 kernel. (#188227)
- Fix up SCSI errors with mymusix usb mp3 player (#186187)

* Mon Apr 24 2006 Dave Jones <davej@redhat.com>
- 2.6.16.11

* Wed Apr 19 2006 Dave Jones <davej@redhat.com>
- Enable PCI MSI.

* Wed Apr 19 2006 David Woodhouse <dwmw2@redhat.com> [2.6.16-1.2096_FC5]
- 2.6.16.9

* Wed Apr 19 2006 David Woodhouse <dwmw2@redhat.com>
- 2.6.16.8

* Tue Apr 18 2006 Dave Jones <davej@redhat.com>
- 2.6.16.7
- Add missing %preuninstall for -kdump kernels. (#189100)

* Mon Apr 17 2006 Dave Jones <davej@redhat.com>
- 2.6.16.6
- Disable the SMP alternatives patch for now.
- Revive Xen.

* Mon Apr 17 2006 David Woodhouse <dwmw2@redhat.com>
- Add include/{mtd,rdma,keys} directories to kernel-devel package

* Sun Apr 16 2006 Dave Jones <davej@redhat.com>
- 2.6.16.5

* Fri Apr  7 2006 Dave Jones <davej@redhat.com>
- 2.6.16.2

* Tue Apr  4 2006 Dave Jones <davej@redhat.com>
- Reenable non-standard serial ports. (#187466)
- Reenable snd-es18xx for x86-32 (#187733)

* Sun Apr 2 2006 David Woodhouse <dwmw2@redhat.com>
- Alternative (and optional) disable for R300 DRI.

* Fri Mar 31 2006 David Woodhouse <dwmw2@redhat.com>
- Send standard WEXT events on softmac assoc/disassociation.

* Wed Mar 27 2006 Dave Jones <davej@redhat.com>
- Enable SMP alternatives for x86/x86-64
- Temporarily disable Xen.
- Re-add kernel-smp-586

* Tue Mar 26 2006 Dave Jones <davej@redhat.com> [2.6.16-1.2080_FC5]
- 2.6.16.1

* Mon Mar 25 2006 Dave Jones <davej@redhat.com>
- Include patches posted for review for inclusion in 2.6.16.1
- Updated new audit msg types.
- Make acpi-cpufreq 'sticky'
- Fix broken x86-64 32bit vDSO. (#186924)

* Fri Mar 24 2006 Dave Jones <davej@redhat.com>
- Reenable HDLC driver (#186257)
- Reenable ISA NE2000 clones. (#136569)

* Fri Mar 24 2006 David Woodhouse <dwmw2@redhat.com>
- Fix lockup when someone takes the bcm43xx device down while it's
  scanning (#180953)

* Wed Mar 22 2006 David Woodhouse <dwmw2@redhat.com>
- Update the bcm43xx driver to make it work nicely with initscripts
  and NetworkManager without user intervention.

* Tue Mar 21 2006 Dave Jones <davej@redhat.com>
- Improve spinlock scalability on big machines.
- Update exec-shield to Ingo's latest.
  (Incorporates John Reiser's "map the vDSO intelligently" patch
   which increases the efficiency of prelinking - #162797).

* Mon Mar 20 2006 Dave Jones <davej@redhat.com>
- ACPI ecdt uid hack. (#185947)

* Mon Mar 20 2006 Juan Quintela <quintela@redhat.com>
- fix xen vmx in 64 bits.

* Mon Mar 20 2006 Dave Jones <davej@redhat.com>
- 2.6.16

* Sun Mar 19 2006 Dave Jones <davej@redhat.com>
- 2.6.16rc6-git12

* Sat Mar 18 2006 Dave Jones <davej@redhat.com>
- 2.6.16rc6-git10 & git11

* Fri Mar 17 2006 Dave Jones <davej@redhat.com>
- 2.6.16rc6-git8 & git9

* Thu Mar 16 2006 Dave Jones <davej@redhat.com>
- 2.6.16rc6-git7

* Wed Mar 15 2006 Dave Jones <davej@redhat.com>
- 2.6.16rc6-git5
- Unmark 'print_tainted' as a GPL symbol.

* Tue Mar 14 2006 Dave Jones <davej@redhat.com>
- FC5 final kernel
- 2.6.16-rc6-git3

